@@ -183,3 +183,30 @@ def weather():
 def ipinfo(ip: str = None):
     from QuickStart_Rhy.API.IPinfo import get_ip_info
     return get_ip_info(ip)
+
+
+def largeImage():
+    try:
+        path = sys.argv[2]
+    except IndexError:
+        exit('Usage qs -LG img')
+    else:
+        from QuickStart_Rhy.API import AipImage
+        aip_cli = AipImage.ImageDeal()
+        aip_cli.largeImage(path)
+
+
+def AipNLP():
+    from QuickStart_Rhy.API.AipNLP import AipNLP
+    import pyperclip
+    ct = sys.argv[2:]
+    if not ct:
+        ct = [pyperclip.paste()]
+    NLP = AipNLP()
+    for id, line in enumerate(ct):
+        ct[id] = NLP.get_res(line)
+        if id == 9:
+            print('...')
+        elif id < 9:
+            print(ct[id])
+    pyperclip.copy('\n'.join(ct))
