@@ -1,6 +1,4 @@
 import sys
-import signal
-from QuickStart_Rhy import deal_ctrl_c
 
 
 def upgrade():
@@ -45,14 +43,8 @@ def ftp():
         port = int(port)
     else:
         ip = '127.0.0.1'
-        port = 80
+        port = 8000
     if not ip:
         exit('get ip failed!')
-    print('starting http simple server: address http://%s:%s/' % (ip, port))
-    import http.server
-    Handler = http.server.SimpleHTTPRequestHandler
-    import socketserver
-    host = (ip, port)
-    with socketserver.TCPServer(host, Handler) as httpd:
-        signal.signal(signal.SIGINT, deal_ctrl_c)
-        httpd.serve_forever()
+    from QuickStart_Rhy.NetTools.server import HttpServers
+    HttpServers(ip, port).start()
